Pure Python Jeelink LaCrosse Library
====================================

|BuildStatus| |Coveralls| |CodeClimate|



Requirements
------------

This libray works with the `Jeelink`_ USB RF adapter and the arduino `sketch`_ hosted on the `FHEM`_ website.


.. _Jeelink: https://www.digitalsmarties.net/products/jeelink
.. _sketch: https://svn.fhem.de/trac/browser/trunk/fhem/contrib/arduino/36_LaCrosse-LaCrosseITPlusReader.zip
.. _FHEM: https://fhem.de/commandref.html

.. |BuildStatus| image:: https://travis-ci.org/hthiery/python-lacrosse.png?branch=master
                 :target: https://travis-ci.org/hthiery/python-lacrosse
.. |CodeClimate| image:: https://api.codeclimate.com/v1/badges/fc83491ef0ae81080882/maintainability
				 :target: https://codeclimate.com/github/hthiery/python-lacrosse/maintainability
				 :alt: Maintainability
.. |Coveralls|   image:: https://coveralls.io/repos/github/hthiery/python-lacrosse/badge.svg?branch=master
                 :target: https://coveralls.io/github/hthiery/python-lacrosse?branch=master
